==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_tb() {
            return 1;
        }
        get_t4() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return MoneyFlowIndexIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get up() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.uq));
        }
        set up(a) {
            this.h(MoneyFlowIndexIndicator.uq, a);
        }
        ua() {
            return this.up;
        }
        uj(a) {
            this.up = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.um(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();

==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicator = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
        }
        get_to() {
            return 1;
        }
        get_uh() {
            return new MoneyFlowIndexIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return MoneyFlowIndexIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u2() {
            return typeGetValue(this.c(MoneyFlowIndexIndicator.u3));
        }
        set u2(a) {
            this.h(MoneyFlowIndexIndicator.u3, a);
        }
        un() {
            return this.u2;
        }
        uw(a) {
            this.u2 = a;
        }
    }
    MoneyFlowIndexIndicator.$t = /*@__PURE__*/ markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
    MoneyFlowIndexIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.uz(14, MoneyFlowIndexIndicator.$);
    return MoneyFlowIndexIndicator;
})();
